package com.ruoyi.system.service;

import java.util.Date;
import java.util.List;
import com.ruoyi.system.domain.UserWork;
import com.ruoyi.system.domain.dto.GetUserPublishWorkDto;
import com.ruoyi.system.domain.dto.UserPublishWorkDetailDto;
import com.ruoyi.system.domain.dto.UserPublishWorkMoreDto;
import com.ruoyi.system.domain.dto.UserWorkReviewDto;

/**
 * 用户作品Service接口
 * 
 * @author haotian
 * @date 2024-10-23
 */
public interface IUserWorkService 
{
    /**
     * 查询用户作品
     * 
     * @param workId 用户作品主键
     * @return 用户作品
     */
    public UserWork selectUserWorkByWorkId(Long workId);

    /**
     * 查询用户作品列表
     * 
     * @param userWork 用户作品
     * @return 用户作品集合
     */
    public List<UserWork> selectUserWorkList(UserWork userWork);

    /*
    * 获取所有不是草稿的作品
    * */
    public List<UserWork> selectUserPublishWorkList(Long userId);


    /**
     * 新增用户作品
     * 
     * @param userWork 用户作品
     * @return 结果
     */
    public int insertUserWork(UserWork userWork);

    /**
     * 修改用户作品
     * 
     * @param userWork 用户作品
     * @return 结果
     */
    public int updateUserWork(UserWork userWork);

    /**
     * 批量删除用户作品
     * 
     * @param workIds 需要删除的用户作品主键集合
     * @return 结果
     */
    public int deleteUserWorkByWorkIds(Long[] workIds);

    /**
     * 删除用户作品信息
     * 
     * @param workId 用户作品主键
     * @return 结果
     */
    public int deleteUserWorkByWorkId(Long workId);

    public Long getUserWorkCount(String workStatus);

    /*
    * 内容审核获取用户作品列表
    * */
    public List<UserWorkReviewDto> getAllUserWork(UserWork userWork);

    /*
    *
    * 查看发布作品详情
    * */
    public UserPublishWorkDetailDto getUserPublishWorkDetail(Long workId);

    /*
    * 更多--查看用户发布作品
    * */
    public List<UserPublishWorkDetailDto> getUserPublishWorkList();

    /*
    * 更多--他人主页--他的发布
    * */
    public List<UserPublishWorkMoreDto> getUserPublishWorkMore(Long userId);

    /**
     *
     * 我的--查看自己发布作品列表
     * */
    public List<GetUserPublishWorkDto> getUserPublishWork(Long userId);

}
