package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.UserWork;
import com.ruoyi.system.service.IUserWorkService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户作品Controller
 * 
 * @author haotian
 * @date 2024-10-23
 */
@RestController
@RequestMapping("/system/work")
public class UserWorkController extends BaseController
{
    @Autowired
    private IUserWorkService userWorkService;

    /**
     * 查询用户作品列表
     */
    @PreAuthorize("@ss.hasPermi('system:work:list')")
    @GetMapping("/list")
    public TableDataInfo list(UserWork userWork)
    {
        startPage();
        List<UserWork> list = userWorkService.selectUserWorkList(userWork);
        return getDataTable(list);
    }

    /**
     * 导出用户作品列表
     */
    @PreAuthorize("@ss.hasPermi('system:work:export')")
    @Log(title = "用户作品", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, UserWork userWork)
    {
        List<UserWork> list = userWorkService.selectUserWorkList(userWork);
        ExcelUtil<UserWork> util = new ExcelUtil<UserWork>(UserWork.class);
        util.exportExcel(response, list, "用户作品数据");
    }

    /**
     * 获取用户作品详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:work:query')")
    @GetMapping(value = "/{workId}")
    public AjaxResult getInfo(@PathVariable("workId") Long workId)
    {
        return success(userWorkService.selectUserWorkByWorkId(workId));
    }

    /**
     * 新增用户作品
     */
    @PreAuthorize("@ss.hasPermi('system:work:add')")
    @Log(title = "用户作品", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody UserWork userWork)
    {
        return toAjax(userWorkService.insertUserWork(userWork));
    }

    /**
     * 修改用户作品
     */
    @PreAuthorize("@ss.hasPermi('system:work:edit')")
    @Log(title = "用户作品", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody UserWork userWork)
    {
        return toAjax(userWorkService.updateUserWork(userWork));
    }

    /**
     * 删除用户作品
     */
    @PreAuthorize("@ss.hasPermi('system:work:remove')")
    @Log(title = "用户作品", businessType = BusinessType.DELETE)
	@DeleteMapping("/{workIds}")
    public AjaxResult remove(@PathVariable Long[] workIds)
    {
        return toAjax(userWorkService.deleteUserWorkByWorkIds(workIds));
    }
}
